'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var bodyParser = _interopDefault(require('body-parser'));
var asyncHandler = _interopDefault(require('express-async-handler'));
var fs = _interopDefault(require('fs-extra'));
var hasha = _interopDefault(require('hasha'));
var path = _interopDefault(require('path'));

var doCommitAction = function doCommitAction(action, options) {
  try {
    var absFilePath = path.join(options.cwd, action.file_path);

    var _temp4 = function () {
      if (action.action === "create" || action.action === "update") {
        return Promise.resolve(fs.writeFile(absFilePath, action.content, action.encoding === "base64" ? "base64" : "utf8")).then(function () {});
      } else {
        var _temp5 = function () {
          if (action.action === "delete") {
            return Promise.resolve(fs.unlink(absFilePath)).then(function () {});
          }
        }();

        if (_temp5 && _temp5.then) return _temp5.then(function () {});
      }
    }();

    return Promise.resolve(_temp4 && _temp4.then ? _temp4.then(function () {}) : void 0);
  } catch (e) {
    return Promise.reject(e);
  }
};

var fileToTree = function fileToTree(filePath, options) {
  try {
    var _exit7 = false;
    var absFilePath = path.join(options.cwd, filePath);
    return Promise.resolve(fs.pathExists(absFilePath)).then(function (_fs$pathExists3) {
      if (!_fs$pathExists3) {
        _exit7 = true;
        return;
      }

      return Promise.resolve(fs.stat(absFilePath)).then(function (stat) {
        if (stat.isDirectory()) {
          return {
            id: "a67a42c0ff0435776c2873d06ff6ec7cd8940be3",
            mode: "040000",
            name: path.basename(filePath),
            path: filePath,
            type: "tree"
          };
        } else {
          return Promise.resolve(fs.readFile(absFilePath)).then(function (content) {
            var hash = hasha(content);
            return {
              id: hash,
              mode: "100644",
              name: path.basename(filePath),
              path: filePath,
              type: "blob"
            };
          });
        }
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

var applyMiddlewares = function applyMiddlewares(app, options) {
  try {
    var prefix = options.prefix || "";
    app.get(prefix + "/api/v4/projects/:projectId/repository/branches/:branch", branches(options));
    app.get(prefix + "/api/v4/projects/:projectId/repository/tree", tree(options));
    app.get(prefix + "/api/v4/projects/:projectId/repository/files/*", readFile(options));
    app.post(prefix + "/api/v4/projects/:projectId/repository/commits", bodyParser.json(), commit(options));
    return Promise.resolve();
  } catch (e) {
    return Promise.reject(e);
  }
};

var branches = function branches(options) {
  return asyncHandler(function (req, res, next) {
    try {
      var branch = req.params.branch;
      res.send({
        name: branch,
        commit: {
          id: branch
        }
      });
      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  });
};

var tree = function tree(options) {
  return asyncHandler(function (req, res, next) {
    try {
      var _exit3 = false;
      var basePath = req.query.path;
      var absBasePath = path.join(options.cwd, basePath);
      return Promise.resolve(fs.pathExists(absBasePath)).then(function (_fs$pathExists) {
        var _exit2 = false;

        function _temp(_fs$stat) {
          if (!_fs$pathExists && !_fs$stat.isDirectory) {
            _exit3 = true;
            return next();
          }

          return Promise.resolve(fs.readdir(absBasePath)).then(function (files) {
            return Promise.resolve(Promise.all(files.map(function (fileName) {
              return fileToTree(path.join(basePath, fileName), options);
            }))).then(function (treeFiles) {
              res.send(treeFiles);
            });
          });
        }

        return _fs$pathExists ? _temp(!_fs$pathExists && fs.stat(absBasePath)) : Promise.resolve(!_fs$pathExists && fs.stat(absBasePath)).then(_temp);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  });
};

var readFile = function readFile(options) {
  return asyncHandler(function (req, res, next) {
    try {
      var _exit5 = false;
      var absFilePath = path.join(options.cwd, req.params["0"]);
      return Promise.resolve(fs.pathExists(absFilePath)).then(function (_fs$pathExists2) {
        if (!_fs$pathExists2) {
          _exit5 = true;
          return next();
        }

        return Promise.resolve(fs.stat(absFilePath)).then(function (stat) {
          return stat.isDirectory() ? next() : Promise.resolve(fs.readFile(absFilePath)).then(function (content) {
            var hash = hasha(content);
            res.send({
              blob_id: hash,
              commit_id: "",
              content: content.toString("base64"),
              content_sha256: hash,
              encoding: "base64",
              file_name: path.basename(req.params["0"]),
              file_path: req.params["0"],
              last_commit_id: "",
              ref: "master",
              size: content.length
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  });
};

var commit = function commit(options) {
  return asyncHandler(function (req, res, next) {
    try {
      var actions = req.body.actions || [];
      return Promise.resolve(Promise.all(actions.map(function (action) {
        return doCommitAction(action, options);
      }))).then(function () {
        res.send({
          ok: true
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  });
};

exports.applyMiddlewares = applyMiddlewares;
//# sourceMappingURL=dev-server.cjs.development.js.map
